==> php55-owncloud-8.2.0.tgz: share/owncloud/apps/files/l10n/is.js <==
OC.L10N.register(
    "files",
    {
    "Could not move %s - File with this name already exists" : "Gat ekki fært %s - Skrá með þessu nafni er þegar til",
    "Could not move %s" : "Gat ekki fært %s",
    "No file was uploaded. Unknown error" : "Engin skrá var send inn. Óþekkt villa.",
    "There is no error, the file uploaded with success" : "Engin villa, innsending heppnaðist",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Innsend skrá er stærri en upload_max stillingin í php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Innsenda skráin er stærri en MAX_FILE_SIZE sem skilgreint er í HTML sniðinu.",
    "The uploaded file was only partially uploaded" : "Einungis hluti af innsendri skrá skilaði sér",
    "No file was uploaded" : "Engin skrá skilaði sér",
    "Missing a temporary folder" : "Vantar bráðabirgðamöppu",
    "Failed to write to disk" : "Tókst ekki að skrifa á disk",
    "Invalid directory." : "Ógild mappa.",
    "Files" : "Skrár",
    "Close" : "Loka",
    "Upload cancelled." : "Hætt við innsendingu.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Innsending í gangi. Ef þú ferð af þessari síðu mun innsending misheppnast.",
    "Download" : "Niðurhal",
    "Rename" : "Endurskýra",
    "Delete" : "Eyða",
    "Select" : "Velja",
    "Pending" : "Bíður",
    "Error" : "Villa",
    "{new_name} already exists" : "{new_name} er þegar til",
    "Name" : "Nafn",
    "Size" : "Stærð",
    "Modified" : "Breytt",
    "New" : "Nýtt",
    "File name cannot be empty." : "Nafn skráar má ekki vera tómt",
    "Upload" : "Senda inn",
    "Text file" : "Texta skrá",
    "Folder" : "Mappa",
    "File handling" : "Meðhöndlun skrár",
    "Maximum upload size" : "Hámarks stærð innsendingar",
    "max. possible: " : "hámark mögulegt: ",
    "Save" : "Vista",
    "Settings" : "Stillingar",
    "WebDAV" : "WebDAV",
    "Cancel upload" : "Hætta við innsendingu",
    "No entries found in this folder" : "Engar skrár fundust í þessari möppu",
    "Select all" : "Velja allt",
    "Upload too large" : "Innsend skrá er of stór",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Skrárnar sem þú ert að senda inn eru stærri en hámarks innsendingarstærð á þessum netþjóni.",
    "Files are being scanned, please wait." : "Verið er að skima skrár, vinsamlegast hinkraðu."
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> php55-owncloud-8.2.2.tgz: share/owncloud/apps/files/l10n/is.js <==
OC.L10N.register(
    "files",
    {
    "Could not move %s - File with this name already exists" : "Gat ekki fært %s - Skrá með þessu nafni er þegar til",
    "Could not move %s" : "Gat ekki fært %s",
    "No file was uploaded. Unknown error" : "Engin skrá var send inn. Óþekkt villa.",
    "There is no error, the file uploaded with success" : "Engin villa, innsending heppnaðist",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Innsend skrá er stærri en upload_max stillingin í php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Innsenda skráin er stærri en MAX_FILE_SIZE sem skilgreint er í HTML sniðinu.",
    "The uploaded file was only partially uploaded" : "Einungis hluti af innsendri skrá skilaði sér",
    "No file was uploaded" : "Engin skrá skilaði sér",
    "Missing a temporary folder" : "Vantar bráðabirgðamöppu",
    "Failed to write to disk" : "Tókst ekki að skrifa á disk",
    "Invalid directory." : "Ógild mappa.",
    "Files" : "Skrár",
    "Close" : "Loka",
    "Upload cancelled." : "Hætt við innsendingu.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Innsending í gangi. Ef þú ferð af þessari síðu mun innsending misheppnast.",
    "Download" : "Niðurhal",
    "Rename" : "Endurskýra",
    "Delete" : "Eyða",
    "Select" : "Velja",
    "Pending" : "Bíður",
    "Error" : "Villa",
    "{new_name} already exists" : "{new_name} er þegar til",
    "Name" : "Nafn",
    "Size" : "Stærð",
    "Modified" : "Breytt",
    "New" : "Nýtt",
    "File name cannot be empty." : "Nafn skráar má ekki vera tómt",
    "Upload" : "Senda inn",
    "Text file" : "Texta skrá",
    "Folder" : "Mappa",
    "File handling" : "Meðhöndlun skrár",
    "Maximum upload size" : "Hámarks stærð innsendingar",
    "max. possible: " : "hámark mögulegt: ",
    "Save" : "Vista",
    "Settings" : "Stillingar",
    "WebDAV" : "WebDAV",
    "Cancel upload" : "Hætta við innsendingu",
    "No entries found in this folder" : "Engar skrár fundust í þessari möppu",
    "Select all" : "Velja allt",
    "Upload too large" : "Innsend skrá er of stór",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Skrárnar sem þú ert að senda inn eru stærri en hámarks innsendingarstærð á þessum netþjóni.",
    "Files are being scanned, please wait." : "Verið er að skima skrár, vinsamlegast hinkraðu.",
    "Upload cancelled." : "Hætt við innsendingu."
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
